If using raspisump_alternate.py (running raspisump as a continuous process).

If the checkpid.py recovers the raspisump_alternate.py process it will log it in the following file;

/home/pi/raspi-sump/logs/process_log
